@@ -1,11 +1,20 @@
 """详细文档阅读地址: https://baidu.gitee.io/amis/zh-CN/components"""
 import os
-from typing import Union, List, Optional, Any, Dict
+from typing import Any, Dict, List, Optional, Union
 
 from pydantic import Field
 
-from .constants import LevelEnum, DisplayModeEnum, SizeEnum, TabsModeEnum
-from .types import API, Expression, AmisNode, SchemaNode, Template, BaseAmisModel, OptionsNode, Tpl
+from .constants import DisplayModeEnum, LevelEnum, SizeEnum, TabsModeEnum
+from .types import (
+    API,
+    AmisNode,
+    BaseAmisModel,
+    Expression,
+    OptionsNode,
+    SchemaNode,
+    Template,
+    Tpl,
+)
 from .utils import amis_templates
 
 try:
@@ -18,19 +27,23 @@ BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 class Html(AmisNode):
     """Html"""
+
     type: str = "html"  # 指定为 html 组件
     html: str  # html  当需要获取数据域中变量时，使用 Tpl 。
 
 
 class Icon(AmisNode):
     """图标"""
+
     type: str = "icon"  # 指定组件类型
     className: str = None  # 外层 CSS 类名
     icon: str = None  # icon 名，支持 fontawesome v4 或使用 url
+    vendor: str = None  # icon 厂商，icon默认支持fontawesome v4，如果想要支持 v5 以及 v6 版本的 fontawesome 请设置vendor为空字符串。
 
 
 class Remark(AmisNode):
     """标记"""
+
     type: str = "remark"  # remark
     className: str = None  # 外层 CSS 类名
     content: str = None  # 提示文本
@@ -41,6 +54,7 @@ class Remark(AmisNode):
 
 class Badge(AmisNode):
     """角标"""
+
     mode: str = "dot"  # 角标类型，可以是 dot/text/ribbon
     text: Union[str, int] = None  # 角标文案，支持字符串和数字，在mode='dot'下设置无效
     size: int = None  # 角标大小
@@ -56,7 +70,8 @@ class Badge(AmisNode):
 
 class Page(AmisNode):
     """页面"""
-    __default_template_path__: str = f'{BASE_DIR}/templates/page.html'
+
+    __default_template_path__: str = f"{BASE_DIR}/templates/page.html"
 
     type: str = "page"  # 指定为 Page 组件
     title: SchemaNode = None  # 页面标题
@@ -83,30 +98,35 @@ class Page(AmisNode):
     regions: List[str] = None
 
     def amis_html(
-            self,
-            template_path: str = '',
-            locale: str = 'zh_CN',
-            cdn: str = 'https://unpkg.com',
-            pkg: str = 'amis@1.10.1',
-            site_title: str = 'Amis',
-            site_icon: str = '',
+        self,
+        template_path: str = "",
+        locale: str = "zh_CN",
+        cdn: str = "https://unpkg.com",
+        pkg: str = "amis@1.10.2",
+        site_title: str = "Amis",
+        site_icon: str = "",
+        theme: str = "cxd",
     ):
         """渲染html模板"""
         template_path = template_path or self.__default_template_path__
+        theme_css = f'<link href="{cdn}/{pkg}/sdk/{theme}.css" rel="stylesheet"/>' if theme != "cxd" else ""
         return amis_templates(template_path).safe_substitute(
             {
                 "AmisSchemaJson": self.amis_json(),
-                "locale": locale,
+                "locale": locale.replace("_", "-"),  # Fix #50
                 "cdn": cdn,
                 "pkg": pkg,
                 "site_title": site_title,
                 "site_icon": site_icon,
+                "theme": theme,
+                "theme_css": theme_css,
             }
         )
 
 
 class Divider(AmisNode):
     """分割线"""
+
     type: str = "divider"  # "Divider"
     className: str = None  # 外层 Dom 的类名
     lineStyle: str = None  # 分割线的样式，支持dashed和solid
@@ -114,6 +134,7 @@ class Divider(AmisNode):
 
 class Flex(AmisNode):
     """布局"""
+
     type: str = "flex"  # 指定为 Flex 渲染器
     className: str = None  # css 类名
     justify: str = None  # "start", "flex-start", "center", "end", "flex-end", "space-around", "space-between", "space-evenly"
@@ -127,6 +148,7 @@ class Grid(AmisNode):
 
     class Column(AmisNode):
         """列配置"""
+
         xs: int = None  # "auto"   # 宽度占比： 1 - 12
         ClassName: str = None  # 列类名
         sm: int = None  # "auto"  # 宽度占比： 1 - 12
@@ -145,6 +167,7 @@ class Grid(AmisNode):
 
 class Panel(AmisNode):
     """面板"""
+
     type: str = "panel"  # 指定为 Panel 渲染器
     className: str = None  # "panel-default"  # 外层 Dom 的类名
     headerClassName: str = None  # "panel-heading"  # header 区域的类名
@@ -219,6 +242,7 @@ class Horizontal(AmisNode):
 
 class Action(AmisNode):
     """行为按钮"""
+
     type: str = "button"  # 指定为 Page 渲染器。 button  action
     actionType: str = None  # 【必填】这是 action 最核心的配置，来指定该 action 的作用类型，
     # 支持：ajax、link、url、drawer、dialog、confirm、cancel、prev、next、copy、close。
@@ -239,7 +263,8 @@ class Action(AmisNode):
     disabledTip: str = None  # 被禁用后鼠标停留时弹出该段文字，也可以配置对象类型：字段为title和content。可用 ${xxx} 取值。
     tooltipPlacement: str = None  # 如果配置了tooltip或者disabledTip，指定提示信息位置，可配置top、bottom、left、right。
     close: Union[
-        bool, str] = None  # 当action配置在dialog或drawer的actions中时，配置为true指定此次操作完后关闭当前dialog或drawer。当值为字符串，并且是祖先层弹框的名字的时候，会把祖先弹框关闭掉。
+        bool, str
+    ] = None  # 当action配置在dialog或drawer的actions中时，配置为true指定此次操作完后关闭当前dialog或drawer。当值为字符串，并且是祖先层弹框的名字的时候，会把祖先弹框关闭掉。
     required: List[str] = None  # 配置字符串数组，指定在form中进行操作之前，需要指定的字段名的表单项通过验证
     # primary:bool=None
     onClick: str = None  # 自定义点击事件 通过字符串形式的 onClick 来定义点击事件，这个字符串会转成 JavaScript 函数
@@ -252,47 +277,50 @@ class ActionType:
     """行为按钮类型"""
 
     class Ajax(Action):
-        actionType: str = 'ajax'  # 点击后显示一个弹出框
+        actionType: str = "ajax"  # 点击后显示一个弹出框
         api: API = None  # 请求地址，参考 api 格式说明。
         redirect: Template = None  # 指定当前请求结束后跳转的路径，可用 ${xxx} 取值。
         feedback: "Dialog" = None  # 如果 ajax 类型的，当 ajax 返回正常后，还能接着弹出一个 dialog 做其他交互。返回的数据可用于这个 dialog 中。格式可参考Dialog
         messages: dict = None  # success：ajax 操作成功后提示，可以不指定，不指定时以 api 返回为准。failed：ajax 操作失败提示。
 
     class Dialog(Action):
-        actionType: str = 'dialog'  # 点击后显示一个弹出框
+        actionType: str = "dialog"  # 点击后显示一个弹出框
         dialog: Union["Dialog", "Service", SchemaNode]  # 指定弹框内容，格式可参考Dialog
         nextCondition: bool = None  # 可以用来设置下一条数据的条件，默认为 true。
 
     class Drawer(Action):
-        actionType: str = 'drawer'  # 点击后显示一个侧边栏
+        actionType: str = "drawer"  # 点击后显示一个侧边栏
         drawer: Union["Drawer", "Service", SchemaNode]  # 指定弹框内容，格式可参考Drawer
 
     class Copy(Action):
-        actionType: str = 'copy'  # 复制一段内容到粘贴板
+        actionType: str = "copy"  # 复制一段内容到粘贴板
         content: Template  # 指定复制的内容。可用 ${xxx} 取值。
         copyFormat: str = None  # 可以通过 copyFormat 设置复制的格式，默认是文本 text/html
 
     class Url(Action):
         """直接跳转"""
-        actionType: str = 'url'  # 直接跳转
+
+        actionType: str = "url"  # 直接跳转
         url: str  # 按钮点击后，会打开指定页面。可用 ${xxx} 取值。
         blank: bool = None  # false 如果为 true 将在新 tab 页面打开。
 
     class Link(Action):
         """单页跳转"""
-        actionType: str = 'link'  # 单页跳转
+
+        actionType: str = "link"  # 单页跳转
         link: str  # 用来指定跳转地址，跟 url 不同的是，这是单页跳转方式，不会渲染浏览器，请指定 amis 平台内的页面。可用 ${xxx} 取值。
 
 
 class PageSchema(AmisNode):
     """页面配置"""
+
     label: str = None  # 菜单名称。
-    icon: str = 'fa fa-flash'  # 菜单图标，比如：'fa fa-file'.
+    icon: str = "fa fa-flash"  # 菜单图标，比如：'fa fa-file'. 详细图标参考：http://www.fontawesome.com.cn/faicons/
     url: str = None  # 页面路由路径，当路由命中该路径时，启用当前页面。当路径不是 / 打头时，会连接父级路径。
     # 比如：父级的路径为 folder，而此时配置 pageA, 那么当页面地址为 /folder/pageA 时才会命中此页面。
     # 当路径是 / 开头如： /crud/list 时，则不会拼接父级路径。
     # 另外还支持 /crud/view/:id 这类带参数的路由，页面中可以通过 ${params.id} 取到此值。
-    schema_: Union[Page, "Iframe"] = Field(None, alias='schema')  # 页面的配置，具体配置请前往 Page 页面说明
+    schema_: Union[Page, "Iframe"] = Field(None, alias="schema")  # 页面的配置，具体配置请前往 Page 页面说明
     schemaApi: API = None  # 如果想通过接口拉取，请配置。返回路径为 json>data。schema 和 schemaApi 只能二选一。
     link: str = None  # 如果想配置个外部链接菜单，只需要配置 link 即可。
     redirect: str = None  # 跳转，当命中当前页面时，跳转到目标页面。
@@ -305,9 +333,9 @@ class PageSchema(AmisNode):
 
     def as_tabs_item(self, tabs_extra: Dict[str, Any] = None, item_extra: Dict[str, Any] = None):
         if self.children:
-            tab = Tabs(
-                tabs=[item.as_tabs_item(tabs_extra, item_extra) for item in self.children]
-            ).update_from_dict(tabs_extra or {})
+            tab = Tabs(tabs=[item.as_tabs_item(tabs_extra, item_extra) for item in self.children]).update_from_dict(
+                tabs_extra or {}
+            )
         elif self.schema_:
             tab = self.schema_
             if isinstance(tab, Iframe):
@@ -327,7 +355,8 @@ class PageSchema(AmisNode):
 
 class App(Page):
     """多页应用"""
-    __default_template_path__: str = f'{BASE_DIR}/templates/app.html'
+
+    __default_template_path__: str = f"{BASE_DIR}/templates/app.html"
     type: str = "app"
     api: API = None  # 页面配置接口，如果你想远程拉取页面配置请配置。返回配置路径 json>data>pages，具体格式请参考 pages 属性。
     brandName: str = None  # 应用名称
@@ -344,7 +373,8 @@ class App(Page):
 
 class ButtonGroup(AmisNode):
     """按钮组"""
-    type: str = 'button-group'
+
+    type: str = "button-group"
     buttons: List[Action]  # 行为按钮组
     className: str = None  # 外层 Dom 的类名
     vertical: bool = None  # 是否使用垂直模式
@@ -352,7 +382,8 @@ class ButtonGroup(AmisNode):
 
 class Custom(AmisNode):
     """自定义组件"""
-    type: str = 'custom'
+
+    type: str = "custom"
     id: str = None  # 节点 id
     name: str = None  # 节点 名称
     className: str = None  # 节点 class
@@ -365,6 +396,7 @@ class Custom(AmisNode):
 
 class Service(AmisNode):
     """功能型容器"""
+
     type: str = "service"  # 指定为 service 渲染器
     name: str = None  # 节点 名称
     data: dict = None  #
@@ -433,7 +465,8 @@ class AnchorNav(AmisNode):
 
 class ButtonToolbar(AmisNode):
     """按钮工具栏"""
-    type: str = 'button-toolbar'
+
+    type: str = "button-toolbar"
     buttons: List[Action]  # 行为按钮组
 
 
@@ -463,7 +496,8 @@ class Validation(BaseAmisModel):
 
 class FormItem(AmisNode):
     """表单项通用"""
-    type: str = 'input-text'  # 指定表单项类型
+
+    type: str = "input-text"  # 指定表单项类型
     className: str = None  # 表单最外层类名
     inputClassName: str = None  # 表单控制器类名
     labelClassName: str = None  # label 的类名
@@ -513,7 +547,7 @@ class Form(AmisNode):
     initApi: API = None  # Form 用来获取初始数据的 api。
     rules: list = None  # 表单组合校验规则 Array<{rule:string;message:string}>
     interval: int = None  # 刷新时间(最低 3000)
-    silentPolling: bool = False  # 配置刷新时是否显示加载动画
+    silentPolling: bool = None  # False  # 配置刷新时是否显示加载动画
     stopAutoRefreshWhen: str = None  # 通过表达式 来配置停止刷新的条件
     initAsyncApi: API = None  # Form 用来获取初始数据的 api,与 initApi 不同的是，会一直轮询请求该接口，直到返回 finished 属性为 true 才 结束。
     initFetch: bool = None  # 设置了 initApi 或者 initAsyncApi 后，默认会开始就发请求，设置为 false 后就不会起始就请求接口
@@ -544,8 +578,29 @@ class Form(AmisNode):
     debug: bool = None
 
 
+class InputSubForm(FormItem):
+    """子表单"""
+
+    type: str = "input-sub-form"
+    multiple: bool = None  # False # 是否为多选模式
+    labelField: str = None  # 当值中存在这个字段，则按钮名称将使用此字段的值来展示。
+    btnLabel: str = None  # "设置" # 按钮默认名称
+    minLength: int = None  # 0 # 限制最小个数。
+    maxLength: int = None  # 0 # 限制最大个数。
+    draggable: bool = None  # 是否可拖拽排序
+    addable: bool = None  # 是否可新增
+    removable: bool = None  # 是否可删除
+    addButtonClassName: str = None  # "``" # 新增按钮 CSS 类名
+    itemClassName: str = None  # "``" # 值元素 CSS 类名
+    itemsClassName: str = None  # "``" # 值包裹元素 CSS 类名
+    form: Form = None  # 子表单配置，同 Form
+    addButtonText: str = None  # "``" # 自定义新增一项的文本
+    showErrorMsg: bool = None  # True # 是否在左下角显示报错信息
+
+
 class Button(FormItem):
     """按钮"""
+
     className: str = None  # 指定添加 button 类名
     href: str = None  # 点击跳转的地址，指定此属性 button 的行为和 a 链接一致
     size: str = None  # 设置按钮大小 'xs'|'sm'|'md'|'lg'
@@ -563,11 +618,12 @@ class Button(FormItem):
 
 class InputArray(FormItem):
     """数组输入框"""
-    type: str = 'input-array'
+
+    type: str = "input-array"
     items: FormItem = None  # 配置单项表单类型
     addable: bool = None  # 是否可新增。
     removable: bool = None  # 是否可删除
-    draggable: bool = False  # 是否可以拖动排序, 需要注意的是当启用拖动排序的时候，会多一个$id 字段
+    draggable: bool = None  # False  # 是否可以拖动排序, 需要注意的是当启用拖动排序的时候，会多一个$id 字段
     draggableTip: str = None  # 可拖拽的提示文字，默认为："可通过拖动每行中的【交换】按钮进行顺序调整"
     addButtonText: str = None  # "新增"  # 新增按钮文字
     minLength: int = None  # 限制最小长度
@@ -576,12 +632,14 @@ class InputArray(FormItem):
 
 class Hidden(FormItem):
     """隐藏字段"""
-    type: str = 'hidden'
+
+    type: str = "hidden"
 
 
 class Checkbox(FormItem):
     """勾选框"""
-    type: str = 'checkbox'
+
+    type: str = "checkbox"
     option: str = None  # 选项说明
     trueValue: Any = None  # 标识真值
     falseValue: Any = None  # 标识假值
@@ -589,7 +647,8 @@ class Checkbox(FormItem):
 
 class Radios(FormItem):
     """单选框"""
-    type: str = 'radios'
+
+    type: str = "radios"
     options: List[Union[dict, str]] = None  # 选项组
     source: API = None  # 动态选项组
     labelField: bool = None  # "label"  # 选项标签字段
@@ -602,7 +661,8 @@ class Radios(FormItem):
 
 class ChartRadios(Radios):
     """单选框"""
-    type: str = 'chart-radios'
+
+    type: str = "chart-radios"
     config: dict = None  # echart 图表配置
     showTooltipOnHighlight: bool = None  # False  # 高亮的时候是否显示 tooltip
     chartValueField: str = None  # "value"  # 图表数值字段名
@@ -610,7 +670,8 @@ class ChartRadios(Radios):
 
 class Checkboxes(FormItem):
     """复选框"""
-    type: str = 'checkboxes'
+
+    type: str = "checkboxes"
     options: OptionsNode = None  # 选项组
     source: API = None  # 动态选项组
     delimiter: str = None  # ","  # 拼接符
@@ -635,7 +696,8 @@ class Checkboxes(FormItem):
 
 class InputCity(FormItem):
     """城市选择器"""
-    type: str = 'location-city'
+
+    type: str = "input-city"
     allowCity: bool = None  # True  # 允许选择城市
     allowDistrict: bool = None  # True  # 允许选择区域
     searchable: bool = None  # False  # 是否出搜索框
@@ -644,7 +706,8 @@ class InputCity(FormItem):
 
 class InputColor(FormItem):
     """颜色选择器"""
-    type: str = 'input-color'
+
+    type: str = "input-color"
     format: str = None  # "hex"  # 请选择 hex、hls、rgb或者rgba。
     presetColors: List[str] = None  # "选择器预设颜色值"  # 选择器底部的默认颜色，数组内为空则不显示默认颜色
     allowCustomColor: bool = None  # True  # 为false时只能选择颜色，使用 presetColors 设定颜色选择范围
@@ -654,7 +717,8 @@ class InputColor(FormItem):
 
 class Combo(FormItem):
     """组合"""
-    type: str = 'combo'
+
+    type: str = "combo"
     formClassName: str = None  # 单组表单项的类名
     addButtonClassName: str = None  # 新增按钮 CSS 类名
     items: List[FormItem] = None  # 组合展示的表单项
@@ -703,36 +767,41 @@ class ConditionBuilder(FormItem):
 
     class Number(Field):
         """数字"""
-        type: str = 'number'
+
+        type: str = "number"
         minimum: float = None  # 最小值
         maximum: float = None  # 最大值
         step: float = None  # 步长
 
     class Date(Field):
         """日期"""
-        type: str = 'date'
+
+        type: str = "date"
         defaultValue: str = None  # 默认值
         format: str = None  # 默认 "YYYY-MM-DD" 值格式
         inputFormat: str = None  # 默认 "YYYY-MM-DD" 显示的日期格式。
 
     class Datetime(Date):
         """日期时间"""
-        type: str = 'datetime'
+
+        type: str = "datetime"
         timeFormat: str = None  # 默认 "HH:mm" 时间格式，决定输入框有哪些。
 
     class Time(Date):
         """时间"""
-        type: str = 'datetime'
+
+        type: str = "datetime"
 
     class Select(Field):
         """下拉选择"""
-        type: str = 'select'
+
+        type: str = "select"
         options: OptionsNode = None  # 选项列表，Array<{label: string, value: any}>
         source: API = None  # 动态选项，请配置 api。
         searchable: bool = None  # 是否可以搜索
         autoComplete: API = None  # 自动提示补全，每次输入新内容后，将调用接口，根据接口返回更新选项。
 
-    type: str = 'condition-builder'
+    type: str = "condition-builder"
     fields: List[Field] = None  # 为数组类型，每个成员表示一个可选字段，支持多个层，配置示例
     className: str = None  # 外层 dom 类名
     fieldClassName: str = None  # 输入字段的类名
@@ -741,7 +810,8 @@ class ConditionBuilder(FormItem):
 
 class Editor(FormItem):
     """代码编辑器"""
-    type: str = 'editor'
+
+    type: str = "editor"
     language: str = None  # "javascript"  # 编辑器高亮的语言，支持通过 ${xxx} 变量获取
     # bat、 c、 coffeescript、 cpp、 csharp、 css、 dockerfile、 fsharp、 go、 handlebars、 html、 ini、 java、
     # javascript、 json、 less、 lua、 markdown、 msdax、 objective-c、 php、 plaintext、 postiats、 powershell、
@@ -753,7 +823,8 @@ class Editor(FormItem):
 
 class Markdown(AmisNode):
     """Markdown渲染"""
-    type: str = 'markdown'
+
+    type: str = "markdown"
     name: str = None  # 字段名，指定该表单项提交时的 key
     value: Union[int, str] = None  # 字段的值
     className: str = None  # 表单最外层类名
@@ -764,7 +835,8 @@ class Markdown(AmisNode):
 
 class InputFile(FormItem):
     """文件上传"""
-    type: str = 'input-file'
+
+    type: str = "input-file"
     receiver: API = None  # 上传文件接口
     accept: str = None  # "text/plain"  # 默认只支持纯文本，要支持其他类型，请配置此属性为文件后缀.xxx
     asBase64: bool = None  # False  # 将文件以base64的形式，赋值给当前组件
@@ -791,11 +863,13 @@ class InputFile(FormItem):
     startChunkApi: API = None  # startChunkApi
     chunkApi: API = None  # chunkApi
     finishChunkApi: API = None  # finishChunkApi
+    autoFill: Dict[str, str] = None  # 上传成功后，可以通过配置 autoFill 将上传接口返回的值填充到某个表单项中（在非表单下暂不支持）
 
 
 class InputExcel(FormItem):
     """解析 Excel"""
-    type: str = 'input-excel'
+
+    type: str = "input-excel"
     allSheets: bool = None  # False  # 是否解析所有 sheet
     parseMode: str = None  # 'array' 或 'object' 解析模式
     includeEmpty: bool = None  # True  # 是否包含空值
@@ -804,7 +878,8 @@ class InputExcel(FormItem):
 
 class InputTable(FormItem):
     """表格"""
-    type: str = 'input-table'  # 指定为 Table 渲染器
+
+    type: str = "input-table"  # 指定为 Table 渲染器
     showIndex: bool = None  # False  # 显示序号
     perPage: int = None  # 设置一页显示多少条数据。10
     addable: bool = None  # False  # 是否可增加一行
@@ -836,14 +911,16 @@ class InputTable(FormItem):
 
 class InputGroup(FormItem):
     """输入框组合"""
-    type: str = 'input-group'
+
+    type: str = "input-group"
     className: str = None  # CSS 类名
     body: List[FormItem] = None  # 表单项集合
 
 
 class Group(InputGroup):
     """表单项组"""
-    type: str = 'group'
+
+    type: str = "group"
     mode: DisplayModeEnum = None  # 展示默认，同 Form 中的模式
     gap: str = None  # 表单项之间的间距，可选：xs、sm、normal
     direction: str = None  # "horizontal"  # 可以配置水平展示还是垂直展示。对应的配置项分别是：vertical、horizontal
@@ -868,7 +945,7 @@ class InputImage(FormItem):
         aspectRatio: float = None  # 限制图片宽高比，格式为浮点型数字，默认 1 即 1:1，
         # 如果要设置 16:9 请设置 1.7777777777777777 即 16 / 9。 如果不想限制比率，请设置空字符串。
 
-    type: str = 'input-image'
+    type: str = "input-image"
     receiver: API = None  # 上传文件接口
     accept: str = None  # ".jpeg,.jpg,.png,.gif"  # 支持的图片类型格式，请配置此属性为图片后缀，例如.jpg,.png
     maxSize: int = None  # 默认没有限制，当设置后，文件大小大于此值将不允许上传。单位为B
@@ -888,12 +965,14 @@ class InputImage(FormItem):
     fixedSize: bool = None  # 是否开启固定尺寸,若开启，需同时设置 fixedSizeClassName
     fixedSizeClassName: str = None  # 开启固定尺寸时，根据此值控制展示尺寸。
     # 例如h-30,即图片框高为 h-30,AMIS 将自动缩放比率设置默认图所占位置的宽度，最终上传图片根据此尺寸对应缩放。
+    autoFill: Dict[str, str] = None  # 上传成功后，可以通过配置 autoFill 将上传接口返回的值填充到某个表单项中（在非表单下暂不支持）
 
 
 class LocationPicker(FormItem):
     """地理位置"""
-    type: str = 'location-picker'
-    vendor: str = 'baidu'  # 地图厂商，目前只实现了百度地图
+
+    type: str = "location-picker"
+    vendor: str = "baidu"  # 地图厂商，目前只实现了百度地图
     ak: str = ...  # 百度地图的 ak  # 注册地址: http://lbsyun.baidu.com/
     clearable: bool = None  # False  # 输入框是否可清空
     placeholder: str = None  # "请选择位置"  # 默认提示
@@ -902,7 +981,8 @@ class LocationPicker(FormItem):
 
 class InputNumber(FormItem):
     """数字输入框"""
-    type: str = 'input-number'
+
+    type: str = "input-number"
     min: Union[int, Template] = None  # 最小值
     max: Union[int, Template] = None  # 最大值
     step: int = None  # 步长
@@ -915,7 +995,8 @@ class InputNumber(FormItem):
 
 class Picker(FormItem):
     """列表选择器"""
-    type: str = 'picker'  # 列表选取，在功能上和 Select 类似，但它能显示更复杂的信息。
+
+    type: str = "picker"  # 列表选取，在功能上和 Select 类似，但它能显示更复杂的信息。
     size: Union[str, SizeEnum] = None  # 支持: xs、sm、md、lg、xl、 full
     options: OptionsNode = None  # 选项组
     source: API = None  # 动态选项组
@@ -934,7 +1015,8 @@ class Picker(FormItem):
 
 class Switch(FormItem):
     """开关"""
-    type: str = 'switch'
+
+    type: str = "switch"
     option: str = None  # 选项说明
     onText: str = None  # 开启时的文本
     offText: str = None  # 关闭时的文本
@@ -944,21 +1026,24 @@ class Switch(FormItem):
 
 class Static(FormItem):
     """静态展示/标签"""
-    type: str = 'static'  # 支持通过配置type为static-xxx的形式，展示其他 非表单项 组件 static-json|static-datetime
+
+    type: str = "static"  # 支持通过配置type为static-xxx的形式，展示其他 非表单项 组件 static-json|static-datetime
 
     class Json(FormItem):
-        type: str = 'static-json'
+        type: str = "static-json"
         value: Union[dict, str]
 
     class Datetime(FormItem):
         """显示日期"""
-        type: str = 'static-datetime'
+
+        type: str = "static-datetime"
         value: Union[int, str]  # 支持10位时间戳: 1593327764
 
 
 class InputText(FormItem):
     """输入框"""
-    type: str = 'input-text'  # input-text|input-url|input-email|input-password|divider
+
+    type: str = "input-text"  # input-text|input-url|input-email|input-password|divider
     options: Union[List[str], List[dict]] = None  # 选项组
     source: Union[str, API] = None  # 动态选项组
     autoComplete: Union[str, API] = None  # 自动补全
@@ -982,23 +1067,27 @@ class InputText(FormItem):
 
 class InputPassword(InputText):
     """密码输框"""
-    type: str = 'input-password'
+
+    type: str = "input-password"
 
 
 class InputRichText(FormItem):
     """富文本编辑器"""
-    type: str = 'input-rich-text'
+
+    type: str = "input-rich-text"
     saveAsUbb: bool = None  # 是否保存为 ubb 格式
     receiver: API = None  # ''  # 默认的图片保存 API
     videoReceiver: API = None  # ''  # 默认的视频保存 API
     size: str = None  # 框的大小，可设置为 md 或者 lg
     options: dict = None  # 需要参考 tinymce 或 froala 的文档
     buttons: List[str] = None  # froala 专用，配置显示的按钮，tinymce 可以通过前面的 options 设置 toolbar 字符串
+    vendor: str = None  # "vendor": "froala" ,配置使用 froala 编辑器
 
 
 class Select(FormItem):
     """下拉框"""
-    type: str = 'select'
+
+    type: str = "select"
     options: OptionsNode = None  # 选项组
     source: API = None  # 动态选项组
     autoComplete: API = None  # 自动提示补全
@@ -1038,7 +1127,8 @@ class Select(FormItem):
 
 class NestedSelect(Select):
     """级联选择器"""
-    type: str = 'nested-select'
+
+    type: str = "nested-select"
     cascade: bool = None  # False  # 设置 true时，当选中父节点时不自动选择子节点。
     withChildren: bool = None  # False  # 设置 true时，选中父节点时，值里面将包含子节点的值，否则只会保留父节点的值。
     onlyChildren: bool = None  # False  # 多选时，选中父节点时，是否只将其子节点加入到值中。
@@ -1050,7 +1140,8 @@ class NestedSelect(Select):
 
 class Textarea(FormItem):
     """多行文本输入框"""
-    type: str = 'textarea'
+
+    type: str = "textarea"
     minRows: int = None  # 最小行数
     maxRows: int = None  # 最大行数
     trimContents: bool = None  # 是否去除首尾空白文本
@@ -1062,7 +1153,8 @@ class Textarea(FormItem):
 
 class InputMonth(FormItem):
     """月份"""
-    type: str = 'input-month'
+
+    type: str = "input-month"
     value: str = None  # 默认值
     format: str = None  # "X"  # 月份选择器值格式，更多格式类型请参考 moment
     inputFormat: str = None  # "YYYY-MM"  # 月份选择器显示格式，即时间戳格式，更多格式类型请参考 moment
@@ -1072,7 +1164,8 @@ class InputMonth(FormItem):
 
 class InputTime(FormItem):
     """时间"""
-    type: str = 'input-time'
+
+    type: str = "input-time"
     value: str = None  # 默认值
     timeFormat: str = None  # "HH:mm"  # 时间选择器值格式，更多格式类型请参考 moment
     format: str = None  # "X"  # 时间选择器值格式，更多格式类型请参考 moment
@@ -1084,7 +1177,8 @@ class InputTime(FormItem):
 
 class InputDatetime(FormItem):
     """日期"""
-    type: str = 'input-datetime'
+
+    type: str = "input-datetime"
     value: str = None  # 默认值
     format: str = None  # "X"  # 日期时间选择器值格式，更多格式类型请参考 文档
     inputFormat: str = None  # "YYYY-MM-DD HH:mm:ss"  # 日期时间选择器显示格式，即时间戳格式，更多格式类型请参考 文档
@@ -1100,7 +1194,8 @@ class InputDatetime(FormItem):
 
 class InputDate(FormItem):
     """日期"""
-    type: str = 'input-date'
+
+    type: str = "input-date"
     value: str = None  # 默认值
     format: str = None  # "X"  # 日期选择器值格式，更多格式类型请参考 文档
     inputFormat: str = None  # "YYYY-DD-MM"  # 日期选择器显示格式，即时间戳格式，更多格式类型请参考 文档
@@ -1122,7 +1217,8 @@ class InputDate(FormItem):
 
 class InputTimeRange(FormItem):
     """时间范围"""
-    type: str = 'input-time-range'
+
+    type: str = "input-time-range"
     timeFormat: str = None  # "HH:mm"  # 时间范围选择器值格式
     format: str = None  # "HH:mm"  # 时间范围选择器值格式
     inputFormat: str = None  # "HH:mm"  # 时间范围选择器显示格式
@@ -1133,7 +1229,8 @@ class InputTimeRange(FormItem):
 
 class InputDatetimeRange(InputTimeRange):
     """日期时间范围"""
-    type: str = 'input-datetime-range'
+
+    type: str = "input-datetime-range"
     ranges: Union[str, List[str]] = None  # "yesterday,7daysago,prevweek,thismonth,prevmonth,prevquarter" 日期范围快捷键，
     # 可选：today,yesterday,1dayago,7daysago,30daysago,90daysago,prevweek,thismonth,thisquarter,prevmonth,prevquarter
     minDate: str = None  # 限制最小日期时间，用法同 限制范围
@@ -1143,19 +1240,22 @@ class InputDatetimeRange(InputTimeRange):
 
 class InputDateRange(InputDatetimeRange):
     """日期范围"""
-    type: str = 'input-date-range'
+
+    type: str = "input-date-range"
     minDuration: str = None  # 限制最小跨度，如： 2days
     maxDuration: str = None  # 限制最大跨度，如：1year
 
 
 class InputMonthRange(InputDateRange):
     """月份范围"""
-    type: str = 'input-month-range'
+
+    type: str = "input-month-range"
 
 
 class Transfer(FormItem):
     """穿梭器"""
-    type: Literal['transfer', 'transfer-picker', 'tabs-transfer', 'tabs-transfer-picker'] = 'transfer'
+
+    type: Literal["transfer", "transfer-picker", "tabs-transfer", "tabs-transfer-picker"] = "transfer"
     options: OptionsNode = None  # 选项组
     source: API = None  # 动态选项组
     delimiter: str = None  # "False"  # 拼接符
@@ -1180,22 +1280,26 @@ class Transfer(FormItem):
 
 class TransferPicker(Transfer):
     """穿梭选择器"""
-    type: str = 'transfer-picker'
+
+    type: str = "transfer-picker"
 
 
 class TabsTransfer(Transfer):
     """组合穿梭器"""
-    type: str = 'tabs-transfer'
+
+    type: str = "tabs-transfer"
 
 
 class TabsTransferPicker(Transfer):
     """组合穿梭选择器"""
-    type: str = 'tabs-transfer-picker'
+
+    type: str = "tabs-transfer-picker"
 
 
 class InputTree(FormItem):
     """树形选择框"""
-    type: str = 'input-tree'
+
+    type: str = "input-tree"
     options: OptionsNode = None  # 选项组
     source: API = None  # 动态选项组
     autoComplete: API = None  # 自动提示补全
@@ -1237,13 +1341,15 @@ class InputTree(FormItem):
 
 class TreeSelect(InputTree):
     """树形选择器"""
-    type: str = 'tree-select'
+
+    type: str = "tree-select"
     hideNodePathLabel: bool = None  # 是否隐藏选择框中已选择节点的路径 label 信息
 
 
 class Image(AmisNode):
     """图片"""
-    type: str = 'image'  # 如果在 Table、Card 和 List 中，为"image"；在 Form 中用作静态展示，为"static-image"
+
+    type: str = "image"  # 如果在 Table、Card 和 List 中，为"image"；在 Form 中用作静态展示，为"static-image"
     className: str = None  # 外层 CSS 类名
     imageClassName: str = None  # 图片 CSS 类名
     thumbClassName: str = None  # 图片缩率图 CSS 类名
@@ -1266,6 +1372,7 @@ class Image(AmisNode):
 
 class Images(AmisNode):
     """图片集"""
+
     type: str = "images"  # 如果在 Table、Card 和 List 中，为"images"；在 Form 中用作静态展示，为"static-images"
     className: str = None  # 外层 CSS 类名
     defaultImage: str = None  # 默认展示图片
@@ -1307,6 +1414,16 @@ class Carousel(AmisNode):
     thumbMode: str = None  # "cover"|"contain"  # 图片默认缩放模式
 
 
+class Mapping(AmisNode):
+    """映射"""
+
+    type: str = "mapping"  # 如果在 Table、Card 和 List 中，为"mapping"；在 Form 中用作静态展示，为"static-mapping"
+    className: str = None  # 外层 CSS 类名
+    placeholder: str = None  # 占位文本
+    map: dict = None  # 映射配置
+    source: API = None  # API 或 数据映射
+
+
 class CRUD(AmisNode):
     """增删改查"""
 
@@ -1366,6 +1483,7 @@ class CRUD(AmisNode):
 
 class TableColumn(AmisNode):
     """列配置"""
+
     type: str = None  # Literal['text','audio','image','link','tpl','mapping','carousel','date',
     # 'progress','status','switch','list','json','operation']
     label: Template = None  # 表头文本内容
@@ -1379,24 +1497,34 @@ class TableColumn(AmisNode):
     searchable: Union[bool, SchemaNode] = None  # False  # 是否可快速搜索  boolean|Schema
     width: Union[str, int] = None  # 列宽
     remark: Remark = None  # 提示信息
-    breakpoint: str = None  # *,ls
+    breakpoint: str = None  # *,ls. 列太多时，内容没办法全部显示完，可以让部分信息在底部显示，可以让用户展开查看详情
+    filterable: Dict[str, Any] = None  # 过滤器配置
+    toggled: bool = None  # 是否默认展开,在列配置中可以通过配置 toggled 为 false 默认不展示这列
+    backgroundScale: int = None  # 可以用来根据数据控制自动分配色阶
 
 
 class ColumnOperation(TableColumn):
     """操作列"""
-    type: str = 'operation'
-    label: Template = None  # "操作"
-    toggled: bool = None  # True
+
+    type: str = "operation"
     buttons: List[Union[Action, AmisNode]] = None
 
 
 class ColumnImage(Image, TableColumn):
     """图片列"""
+
     pass
 
 
 class ColumnImages(Images, TableColumn):
     """图片集列"""
+
+    pass
+
+
+class ColumnMapping(Mapping, TableColumn):
+    """映射列"""
+
     pass
 
 
@@ -1432,6 +1560,7 @@ class Table(AmisNode):
 
 class Chart(AmisNode):
     """图表: https://echarts.apache.org/zh/option.html#title"""
+
     type: str = "chart"  # 指定为 chart 渲染器
     className: str = None  # 外层 Dom 的类名
     body: SchemaNode = None  # 内容容器
@@ -1449,6 +1578,7 @@ class Chart(AmisNode):
 
 class Code(AmisNode):
     """代码高亮"""
+
     type: str = "code"
     className: str = None  # 外层 CSS 类名
     value: str = None  # 显示的颜色值
@@ -1461,6 +1591,7 @@ class Code(AmisNode):
 
 class Json(AmisNode):
     """JSON 展示组件"""
+
     type: str = "json"  # 如果在 Table、Card 和 List 中，为"json"；在 Form 中用作静态展示，为"static-json"
     className: str = None  # 外层 CSS 类名
     value: Union[dict, str] = None  # json 值，如果是 string 会自动 parse
@@ -1474,6 +1605,7 @@ class Json(AmisNode):
 
 class Link(AmisNode):
     """链接"""
+
     type: str = "link"  # 如果在 Table、Card 和 List 中，为"link"；在 Form 中用作静态展示，为"static-link"
     body: str = None  # 标签内文本
     href: str = None  # 链接地址
@@ -1487,6 +1619,7 @@ class Link(AmisNode):
 
 class Log(AmisNode):
     """实时日志"""
+
     type: str = "log"
     source: API = None  # 支持变量,可以初始设置为空，这样初始不会加载，而等这个变量有值的时候再加载
     height: int = None  # 500  # 展示区域高度
@@ -1496,15 +1629,6 @@ class Log(AmisNode):
     encoding: str = None  # "utf-8"  # 返回内容的字符编码
 
 
-class Mapping(AmisNode):
-    """映射"""
-    type: str = "mapping"  # 如果在 Table、Card 和 List 中，为"mapping"；在 Form 中用作静态展示，为"static-mapping"
-    className: str = None  # 外层 CSS 类名
-    placeholder: str = None  # 占位文本
-    map: dict = None  # 映射配置
-    source: API = None  # API 或 数据映射
-
-
 class Property(AmisNode):
     """属性表"""
 
@@ -1515,7 +1639,7 @@ class Property(AmisNode):
         visibleOn: Expression = None  # 显示表达式
         hiddenOn: Expression = None  # 隐藏表达式
 
-    type: str = 'property'
+    type: str = "property"
     className: str = None  # 外层 dom 的类名
     style: dict = None  # 外层 dom 的样式
     labelStyle: dict = None  # 属性名的样式
@@ -1530,6 +1654,7 @@ class Property(AmisNode):
 
 class QRCode(AmisNode):
     """二维码"""
+
     type: str = "qr-code"  # 指定为 QRCode 渲染器
     value: Template  # 扫描二维码后显示的文本，如果要显示某个页面请输入完整 url（"http://..."或"https://..."开头），支持使用 模板
     className: str = None  # 外层 Dom 的类名
@@ -1542,6 +1667,7 @@ class QRCode(AmisNode):
 
 class Video(AmisNode):
     """视频"""
+
     type: str = "video"  # 指定为 video 渲染器
     className: str = None  # 外层 Dom 的类名
     src: str = None  # 视频地址
@@ -1555,6 +1681,7 @@ class Video(AmisNode):
 
 class Alert(AmisNode):
     """提示"""
+
     type: str = "alert"  # 指定为 alert 渲染器
     className: str = None  # 外层 Dom 的类名
     level: str = None  # "info"  # 级别，可以是：info、success、warning 或者 danger
@@ -1568,6 +1695,7 @@ class Alert(AmisNode):
 
 class Dialog(AmisNode):
     """对话框"""
+
     type: str = "dialog"  # 指定为 Dialog 渲染器
     title: SchemaNode = None  # 弹出层标题
     body: SchemaNode = None  # 往 Dialog 内容区加内容
@@ -1583,6 +1711,7 @@ class Dialog(AmisNode):
 
 class Drawer(AmisNode):
     """抽屉"""
+
     type: str = "drawer"  # "drawer" 指定为 Drawer 渲染器
     title: SchemaNode = None  # 弹出层标题
     body: SchemaNode = None  # 往 Drawer 内容区加内容
@@ -1599,17 +1728,22 @@ class Drawer(AmisNode):
 
 class Iframe(AmisNode):
     """Iframe"""
+
     type: str = "iframe"  # 指定为 iFrame 渲染器
     className: str = None  # iFrame 的类名
     frameBorder: list = None  # frameBorder
     style: dict = None  # 样式对象
     src: str = None  # iframe 地址
+    allow: str = None  # allow 配置
+    sandbox: str = None  # sandbox 配置
+    referrerpolicy: str = None  # referrerpolicy 配置
     height: Union[int, str] = None  # "100%"#  iframe 高度
     width: Union[int, str] = None  # "100%" # iframe 宽度
 
 
 class Spinner(AmisNode):
     """加载中"""
+
     type: str = "spinner"
 
 
@@ -1619,6 +1753,7 @@ class TableCRUD(CRUD, Table):
 
 class Avatar(AmisNode):
     """头像"""
+
     type: str = "avatar"
     className: str = None  # 外层 dom 的类名
     fit: str = None  # "cover"  # 图片缩放类型
@@ -1632,6 +1767,7 @@ class Avatar(AmisNode):
 
 class Audio(AmisNode):
     """音频"""
+
     type: str = "audio"  # 指定为 audio 渲染器
     className: str = None  # 外层 Dom 的类名
     inline: bool = None  # True  # 是否是内联模式
@@ -1644,6 +1780,7 @@ class Audio(AmisNode):
 
 class Status(AmisNode):
     """状态"""
+
     type: str = "status"  # 指定为 Status 渲染器
     className: str = None  # 外层 Dom 的类名
     placeholder: str = None  # 占位文本
