@@ -2,10 +2,4 @@ __version__ = "0.1.0"
 
 from ._sqlmodel import SQLModelCrud, SQLModelSelector
 from .base import BaseCrud, RouterMixin
-from .schema import (
-    BaseApiOut,
-    BaseApiSchema,
-    CrudEnum,
-    ItemListSchema,
-    Paginator
-)
+from .schema import BaseApiOut, BaseApiSchema, CrudEnum, ItemListSchema, Paginator
