@@ -1,4 +1,4 @@
-from typing import Any, Callable, List, Type, Union, Optional
+from typing import Any, Callable, List, Optional, Type, Union
 
 from fastapi import APIRouter, Depends
 from pydantic import BaseModel
@@ -7,8 +7,8 @@ from starlette import status
 from starlette.exceptions import HTTPException
 from starlette.requests import Request
 
-from .schema import BaseApiOut, ItemListSchema, CrudEnum, Paginator
-from .utils import schema_create_by_schema, paginator_factory
+from .schema import BaseApiOut, CrudEnum, ItemListSchema, Paginator
+from .utils import schema_create_by_schema
 
 
 class RouterMixin:
@@ -22,14 +22,14 @@ class RouterMixin:
     def get_router(self) -> APIRouter:
         if self.router is None:
             if self.router_prefix is None:
-                self.router_prefix = f'/{self.__class__.__name__.lower()}'
+                self.router_prefix = f"/{self.__class__.__name__.lower()}"
             self.router = APIRouter(prefix=self.router_prefix, tags=[self.router_prefix[1:]])
         if self.router_permission_depend is not None:
             self.router.dependencies.insert(0, Depends(self.router_permission_depend))
         return self.router
 
     def error_no_router_permission(self, request: Request):
-        raise HTTPException(status_code=status.HTTP_401_UNAUTHORIZED, detail='No router permissions')
+        raise HTTPException(status_code=status.HTTP_401_UNAUTHORIZED, detail="No router permissions")
 
 
 class BaseCrud(RouterMixin):
@@ -39,56 +39,52 @@ class BaseCrud(RouterMixin):
     schema_create: Type[BaseModel] = None
     schema_read: Type[BaseModel] = None
     schema_update: Type[BaseModel] = None
-    pk_name: str = 'id'
+    pk_name: str = "id"
     list_per_page_max: int = None
 
-    def __init__(
-            self,
-            schema_model: Type[BaseModel],
-            router: APIRouter = None
-    ):
-        self.paginator: Type[Paginator] = Paginator
+    def __init__(self, schema_model: Type[BaseModel], router: APIRouter = None):
+        self.paginator = Paginator()
         self.schema_model = schema_model or self.schema_model
-        assert self.schema_model, 'schema_model is None'
+        assert self.schema_model, "schema_model is None"
         self.router = router
         RouterMixin.__init__(self)
 
     @property
     def router_prefix(self):
-        return f'/{self.schema_model.__name__.lower()}'
+        return f"/{self.schema_model.__name__.lower()}"
 
     @property
     def schema_name_prefix(self):
         return self.__class__.__name__
 
     def register_crud(
-            self,
-            schema_list: Type[BaseModel] = None,
-            schema_filter: Type[BaseModel] = None,
-            schema_create: Type[BaseModel] = None,
-            schema_read: Type[BaseModel] = None,
-            schema_update: Type[BaseModel] = None,
-            list_max_per_page: int = None,
-            depends_list: List[Depends] = None,
-            depends_read: List[Depends] = None,
-            depends_create: List[Depends] = None,
-            depends_update: List[Depends] = None,
-            depends_delete: List[Depends] = None
+        self,
+        schema_list: Type[BaseModel] = None,
+        schema_filter: Type[BaseModel] = None,
+        schema_create: Type[BaseModel] = None,
+        schema_read: Type[BaseModel] = None,
+        schema_update: Type[BaseModel] = None,
+        list_per_page_max: int = None,
+        depends_list: List[Depends] = None,
+        depends_read: List[Depends] = None,
+        depends_create: List[Depends] = None,
+        depends_update: List[Depends] = None,
+        depends_delete: List[Depends] = None,
     ) -> "BaseCrud":
         self.schema_list = schema_list or self._create_schema_list()
         self.schema_filter = schema_filter or self._create_schema_filter()
         self.schema_create = schema_create or self._create_schema_create()
         self.schema_read = schema_read or self._create_schema_read()
         self.schema_update = schema_update or self._create_schema_update()
-        self.list_per_page_max = list_max_per_page or self.list_per_page_max
-        self.paginator = paginator_factory(perPage_max=self.list_per_page_max)
+        self.list_per_page_max = list_per_page_max or self.list_per_page_max
+        self.paginator = Paginator(perPage_max=self.list_per_page_max)
         self.router.add_api_route(
             "/list",
             self.route_list,
             methods=["POST"],
             response_model=BaseApiOut[ItemListSchema[self.schema_list]],
             dependencies=depends_list,
-            name=CrudEnum.list.value
+            name=CrudEnum.list,
         )
         self.router.add_api_route(
             "/item/{item_id}",
@@ -96,7 +92,7 @@ class BaseCrud(RouterMixin):
             methods=["GET"],
             response_model=BaseApiOut[Union[self.schema_read, List[self.schema_read]]],
             dependencies=depends_read,
-            name=CrudEnum.read.value
+            name=CrudEnum.read,
         )
         self.router.add_api_route(
             "/item",
@@ -104,7 +100,7 @@ class BaseCrud(RouterMixin):
             methods=["POST"],
             response_model=BaseApiOut[Union[int, self.schema_model]],
             dependencies=depends_create,
-            name=CrudEnum.create.value
+            name=CrudEnum.create,
         )
         self.router.add_api_route(
             "/item/{item_id}",
@@ -112,7 +108,7 @@ class BaseCrud(RouterMixin):
             methods=["PUT"],
             response_model=BaseApiOut[int],
             dependencies=depends_update,
-            name=CrudEnum.update.value
+            name=CrudEnum.update,
         )
         self.router.add_api_route(
             "/item/{item_id}",
@@ -120,7 +116,7 @@ class BaseCrud(RouterMixin):
             methods=["DELETE"],
             response_model=BaseApiOut[int],
             dependencies=depends_delete,
-            name=CrudEnum.delete.value
+            name=CrudEnum.delete,
         )
         return self
 
@@ -128,28 +124,21 @@ class BaseCrud(RouterMixin):
         return self.schema_list or self.schema_model
 
     def _create_schema_filter(self):
-        return self.schema_filter or schema_create_by_schema(
-            self.schema_list,
-            f'{self.schema_name_prefix}Filter',
-            set_none=True
-        )
+        return self.schema_filter or schema_create_by_schema(self.schema_list, f"{self.schema_name_prefix}Filter", set_none=True)
 
     def _create_schema_read(self):
-        return self.schema_read or self.schema_list
+        return self.schema_read or self.schema_model
 
     def _create_schema_update(self):
         return self.schema_update or schema_create_by_schema(
             self.schema_model,
-            f'{self.schema_name_prefix}Update',
+            f"{self.schema_name_prefix}Update",
             exclude={self.pk_name},
             set_none=True,
         )
 
     def _create_schema_create(self):
-        return self.schema_create or schema_create_by_schema(
-            self.schema_model,
-            f'{self.schema_name_prefix}Create'
-        )
+        return self.schema_create or schema_create_by_schema(self.schema_model, f"{self.schema_name_prefix}Create")
 
     @property
     def route_list(self) -> Callable[..., Any]:
@@ -172,45 +161,30 @@ class BaseCrud(RouterMixin):
         raise NotImplementedError
 
     async def has_list_permission(
-            self,
-            request: Request,
-            paginator: Optional[Paginator],
-            filters: Optional[BaseModel],
-            **kwargs
+        self,
+        request: Request,
+        paginator: Optional[Paginator],
+        filters: Optional[BaseModel],
+        **kwargs,
     ) -> bool:
         return True
 
-    async def has_create_permission(
-            self,
-            request: Request,
-            obj: Optional[BaseModel],
-            **kwargs
-    ) -> bool:
+    async def has_create_permission(self, request: Request, obj: Optional[BaseModel], **kwargs) -> bool:
         return True
 
-    async def has_read_permission(
-            self,
-            request: Request,
-            item_id: Optional[List[str]],
-            **kwargs
-    ) -> bool:
+    async def has_read_permission(self, request: Request, item_id: Optional[List[str]], **kwargs) -> bool:
         return True
 
     async def has_update_permission(
-            self,
-            request: Request,
-            item_id: Optional[List[str]],
-            obj: Optional[BaseModel],
-            **kwargs
+        self,
+        request: Request,
+        item_id: Optional[List[str]],
+        obj: Optional[BaseModel],
+        **kwargs,
     ) -> bool:
         return True
 
-    async def has_delete_permission(
-            self,
-            request: Request,
-            item_id: Optional[List[str]],
-            **kwargs
-    ) -> bool:
+    async def has_delete_permission(self, request: Request, item_id: Optional[List[str]], **kwargs) -> bool:
         return True
 
     def error_data_handle(self, request: Request):
@@ -220,9 +194,9 @@ class BaseCrud(RouterMixin):
         if isinstance(error, IntegrityError):
             raise HTTPException(
                 status_code=status.HTTP_422_UNPROCESSABLE_ENTITY,
-                detail="Key already exists"
+                detail="Key already exists",
             ) from error
         raise HTTPException(
             status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
-            detail=f"Error Execute SQL：{error}"
+            detail=f"Error Execute SQL：{error}",
         ) from error
