@@ -1,9 +1,10 @@
 import datetime
 from functools import lru_cache
-from typing import Union, Optional, Type, List, Dict, Any, Iterable, Tuple, Callable
+from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Type, Union
 
-from pydantic.datetime_parse import parse_datetime, parse_date
-from pydantic.fields import ModelField
+from pydantic import BaseConfig
+from pydantic.datetime_parse import parse_date, parse_datetime
+from pydantic.fields import FieldInfo, ModelField
 from pydantic.utils import smart_deepcopy
 from sqlalchemy import Column
 from sqlalchemy.engine import Row
@@ -13,17 +14,18 @@ from sqlalchemy.sql.elements import Label
 from sqlmodel import SQLModel
 
 SQLModelField = Union[str, InstrumentedAttribute]
-SQLModelListField = Union[Type[SQLModel], SQLModelField]
+SqlField = Union[InstrumentedAttribute, Label]
+SQLModelListField = Union[Type[SQLModel], SQLModelField, SqlField]
 
 
 class SQLModelFieldParser:
-    _name_format = '{model_name}_{field_name}'
-    _alias_format = '{table_name}__{field_key}'
+    _name_format = "{model_name}_{field_name}"
+    _alias_format = "{table_name}__{field_key}"
 
     def __init__(self, default_model: Type[SQLModel]):
         self.default_model = default_model
 
-    def get_modelfield(self, field: Union[ModelField, SQLModelField], deepcopy: bool = False) -> Optional[ModelField]:
+    def get_modelfield(self, field: Union[ModelField, SQLModelField, Label], deepcopy: bool = False) -> Optional[ModelField]:
         """pydantic ModelField"""
         modelfield = None
         if isinstance(field, InstrumentedAttribute):
@@ -39,6 +41,8 @@ class SQLModelFieldParser:
                 modelfield = self.default_model.__fields__[field]
         elif isinstance(field, ModelField):
             modelfield = field
+        elif isinstance(field, Label):
+            return _get_label_modelfield(field)
         else:  # other
             return None
         if deepcopy:
@@ -55,20 +59,32 @@ class SQLModelFieldParser:
 
     def get_alias(self, field: Union[Column, SQLModelField, Label]) -> str:
         if isinstance(field, Column):
-            return field.name if field.table.name == self.default_model.__tablename__ else self._alias_format.format(
-                table_name=field.table.name, field_key=field.name)
+            return (
+                field.name
+                if field.table.name == self.default_model.__tablename__
+                else self._alias_format.format(table_name=field.table.name, field_key=field.name)
+            )
         elif isinstance(field, InstrumentedAttribute):
-            return field.key if field.class_.__tablename__ == self.default_model.__tablename__ else self._alias_format.format(
-                table_name=field.class_.__tablename__, field_key=field.expression.key)
+            return (
+                field.key
+                if field.class_.__tablename__ == self.default_model.__tablename__
+                else self._alias_format.format(
+                    table_name=field.class_.__tablename__,
+                    field_key=field.expression.key,
+                )
+            )
         elif isinstance(field, Label):
             return field.key
         elif isinstance(field, str) and field in self.default_model.__fields__:
             return field
-        return ''
+        return ""
 
     def get_name(self, field: InstrumentedAttribute) -> str:
-        return field.key if field.class_.__tablename__ == self.default_model.__tablename__ else self._name_format.format(
-            model_name=field.class_.__tablename__, field_name=field.key)
+        return (
+            field.key
+            if field.class_.__tablename__ == self.default_model.__tablename__
+            else self._name_format.format(model_name=field.class_.__tablename__, field_name=field.key)
+        )
 
     def get_row_keys(self, row: Row) -> List[str]:
         """sqlalchemy row keys"""
@@ -102,8 +118,11 @@ class SQLModelFieldParser:
 
         return None
 
-    def filter_insfield(self, fields: Iterable[Union[SQLModelListField, Any]], save_class: Tuple[type] = None) -> \
-            List[Union[InstrumentedAttribute, Any]]:
+    def filter_insfield(
+        self,
+        fields: Iterable[Union[SQLModelListField, Any]],
+        save_class: Tuple[Union[type, Tuple[Any, ...]], ...] = None,
+    ) -> List[Union[InstrumentedAttribute, Any]]:
         result = []
         for field in fields:
             insfield = self.get_insfield(field)
@@ -113,11 +132,11 @@ class SQLModelFieldParser:
                 result.extend(self.get_sqlmodel_insfield(field))
             elif save_class and isinstance(field, save_class):
                 result.append(field)
-        return result
+        return sorted(set(result), key=result.index)  # 去重复并保持原顺序
 
 
 @lru_cache()
-def get_python_type_parse(field: Union[InstrumentedAttribute, Column]) -> Callable:
+def get_python_type_parse(field: Union[InstrumentedAttribute, Column, Label]) -> Callable:
     try:
         python_type = field.expression.type.python_type
         if issubclass(python_type, datetime.date):
@@ -127,3 +146,23 @@ def get_python_type_parse(field: Union[InstrumentedAttribute, Column]) -> Callab
         return python_type
     except NotImplementedError:
         return str
+
+
+def _get_label_modelfield(label: Label) -> ModelField:
+    modelfield = getattr(label, "__ModelField__", None)
+    if modelfield is None:
+        try:
+            python_type = label.expression.type.python_type
+        except NotImplementedError:
+            python_type = str
+        modelfield = ModelField(name=label.key, type_=python_type, class_validators={}, model_config=BaseConfig)
+        label.__ModelField__ = modelfield
+    return modelfield
+
+
+def LabelField(label: Label, field: FieldInfo) -> Label:
+    modelfield = _get_label_modelfield(label)
+    field.alias = label.key
+    modelfield.field_info = field
+    label.__ModelField__ = modelfield
+    return label
