@@ -1,6 +1,6 @@
 from sqlalchemy import create_engine
 
-from fastapi_amis_admin.admin import admin, AdminSite, AdminApp
+from fastapi_amis_admin.admin import AdminApp, AdminSite, admin
 from tests.models import User
 
 
@@ -31,7 +31,7 @@ async def test_register_admin(site: AdminSite):
 
 
 async def test_get_model_admin(site: AdminSite):
-    BlogApp.engine = create_engine('sqlite:///amisadmin2.db?check_same_thread=False')
+    BlogApp.engine = create_engine("sqlite:///amisadmin2.db?check_same_thread=False")
     site.register_admin(BlogApp)
     site.register_router()
     assert site.get_model_admin(User.__tablename__) is None
